import React, { PropTypes } from 'react'
import { ThemeProvider, injectGlobal } from 'styled-components';
import Fonts from './Fonts'
import Reset from './Reset'
import GlobalStyles from './GlobalStyles'
import theme from './theme'
import Pane from './Pane'

const App = ({ children, reset, fonts, globalStyles, ...props }) => {
  return (
    <ThemeProvider theme={theme}>
      <Pane className='UIApp' minHeight='100%' width='100%' display='flex' flexAuto flexDirection='column' {...props}>
        {reset}
        {fonts}
        {globalStyles}
        {children}
      </Pane>
    </ThemeProvider>
  )
}

App.propTypes = {
  children: PropTypes.any,
  reset: PropTypes.element,
  fonts: PropTypes.element,
  globalStyles: PropTypes.element
}

App.defaultProps = {
  reset: <Reset />,
  fonts: <Fonts />,
  globalStyles: <GlobalStyles theme={theme} />
}

export default App
