import React, { PropTypes } from 'react'
import cx from 'classnames'
import {
  SpaceScale,
  SpaceScalePropType
} from './../components/Space'

const TextAlign = {
  LEFT: 'left',
  RIGHT: 'right',
  CENTER: 'center'
}

const parseProps = ({
  textAlign,
  style,
  ...props
}) => {
  const styles = {}

  styles.textAlign = textAlign

  return { style: { ...styles, ...style }, ...props }
}

const withTextAlign = (Comp) => {
  const TextAlignComp = (originalProps) => {
    return React.createElement(Comp, parseProps(originalProps))
  }

  TextAlignComp.propTypes = {
    ...Comp.propTypes,
    textAlign: PropTypes.oneOf(Object.values(TextAlign))
  }

  TextAlignComp.displayName = Comp.displayName

  return TextAlignComp
}

export {
  withTextAlign
}
